@@ -20,7 +20,7 @@
 #include "account-mgr.h"
 #include "configurator.h"
 #include "daemon-mgr.h"
-#include "message-listener.h"
+#include "message-poller.h"
 #include "settings-mgr.h"
 #include "certs-mgr.h"
 #include "rpc/rpc-client.h"
@@ -36,6 +36,7 @@
 #include "filebrowser/auto-update-mgr.h"
 #include "filebrowser/data-mgr.h"
 #include "rpc/local-repo.h"
+#include "rpc/rpc-server.h"
 #include "network-mgr.h"
 #include "server-status-service.h"
 #include "account-info-service.h"
@@ -192,7 +193,7 @@ SeafileApplet::SeafileApplet()
       daemon_mgr_(new DaemonManager),
       main_win_(NULL),
       rpc_client_(new SeafileRpcClient),
-      message_listener_(new MessageListener),
+      message_poller_(new MessagePoller),
       settings_dialog_(new SettingsDialog),
       settings_mgr_(new SettingsManager),
       certs_mgr_(new CertsManager),
@@ -216,7 +217,7 @@ SeafileApplet::~SeafileApplet()
     delete tray_icon_;
     delete certs_mgr_;
     delete settings_dialog_;
-    delete message_listener_;
+    delete message_poller_;
     delete rpc_client_;
     delete daemon_mgr_;
 
@@ -243,6 +244,7 @@ void SeafileApplet::start()
 
     initLog();
 
+    qDebug("client id is %s", toCStr(getUniqueClientId()));
     account_mgr_->start();
 
     certs_mgr_->start();
@@ -270,7 +272,7 @@ void SeafileApplet::start()
     //
     // start daemons
     //
-    daemon_mgr_->startCcnetDaemon();
+    daemon_mgr_->startSeafileDaemon();
 
     connect(daemon_mgr_, SIGNAL(daemonStarted()),
             this, SLOT(onDaemonStarted()));
@@ -282,7 +284,6 @@ void SeafileApplet::onDaemonStarted()
     // start daemon-related services
     //
     rpc_client_->connectDaemon();
-    message_listener_->connectDaemon();
 
     // Sleep 500 millseconds to wait seafile registering services
 
@@ -305,6 +306,7 @@ void SeafileApplet::onDaemonStarted()
     ServerStatusService::instance()->start();
     CustomizationService::instance()->start();
     AccountInfoService::instance()->start();
+    SeafileAppletRpcServer::instance()->start();
 
     account_mgr_->updateServerInfo();
 
@@ -352,6 +354,8 @@ void SeafileApplet::onDaemonStarted()
 
     tray_icon_->start();
     tray_icon_->setState(SeafileTrayIcon::STATE_DAEMON_UP);
+    message_poller_->start();
+
 
 #if defined(Q_OS_WIN32)
     QTimer::singleShot(kIntervalBeforeShowInitVirtualDialog, this, SLOT(checkInitVDrive()));
@@ -365,6 +369,14 @@ void SeafileApplet::onDaemonStarted()
         "client_name", settings_mgr_->getComputerName());
     }
 
+    // Set the device id to the daemon so it can use it when generating commits.
+    // The "client_name" is not set here, but updated each time we call
+    // switch_account rpc.
+    if (rpc_client_->seafileGetConfig("client_id", &value) < 0 ||
+        value.isEmpty() || value != getUniqueClientId()) {
+        rpc_client_->seafileSetConfig("client_id", getUniqueClientId());
+    }
+
     OpenLocalHelper::instance()->checkPendingOpenLocalRequest();
 
     QTimer::singleShot(kIntervalForUpdateRepoProperty,
@@ -689,3 +701,48 @@ QString SeafileApplet::getText(QWidget *parent,
                                  flags,
                                  inputMethodHints);
 }
+
+QString SeafileApplet::getUniqueClientId()
+{
+    // Id file path is `~/Seafile/.seafile-data/id`
+    QFile id_file(QDir(seafApplet->configurator()->seafileDir())
+                  .absoluteFilePath("id"));
+    if (!id_file.exists()) {
+        srand(time(NULL));
+        QString id;
+        while (id.length() < 40) {
+            int r = rand() % 0xff;
+            id += QString("%1").arg(r, 0, 16);
+        }
+        id = id.mid(0, 40);
+
+        if (!id_file.open(QIODevice::WriteOnly)) {
+            errorAndExit(tr("failed to save client id"));
+            return "";
+        }
+
+        id_file.write(id.toUtf8().data());
+        return id;
+    }
+
+    if (!id_file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        errorAndExit(tr("failed to access %1").arg(id_file.fileName()));
+        return "";
+    }
+
+    QTextStream input(&id_file);
+    input.setCodec("UTF-8");
+
+    if (input.atEnd()) {
+        errorAndExit(tr("incorrect client id"));
+        return "";
+    }
+
+    QString id = input.readLine().trimmed();
+    if (id.length() != 40) {
+        errorAndExit(tr("failed to read %1").arg(id_file.fileName()));
+        return "";
+    }
+
+    return id;
+}
