@@ -11,7 +11,7 @@ class DaemonManager;
 class SeafileRpcClient;
 class AccountManager;
 class MainWindow;
-class MessageListener;
+class MessagePoller;
 class SeafileTrayIcon;
 class SettingsManager;
 class SettingsDialog;
@@ -60,6 +60,9 @@ public:
     // ExpandedVars String
     QString readPreconfigureExpandedString(const QString& key, const QString& default_value = QString());
 
+    // Create a unique device id to replace obselete ccnet id
+    QString getUniqueClientId();
+
     // accessors
     AccountManager *accountManager() { return account_mgr_; }
 
@@ -107,7 +110,7 @@ private:
 
     SeafileRpcClient *rpc_client_;
 
-    MessageListener *message_listener_;
+    MessagePoller *message_poller_;
 
     SeafileTrayIcon *tray_icon_;
 
